@@ -46,10 +46,12 @@ class CachedData(object):
 
     def put(self, value):
         self.id = uuid1().hex
+        value = Husky.dumps(value)
         KVStore(config.host, self.name).set(self.id, value, serialize=False)
 
     def get(self, key):
-        return KVStore(config.host, self.name).get(key)
+        res = KVStore(config.host, self.name).get(key)
+        return Husky.loads(res)
 
     def __del__(self):
         pass
\ No newline at end of file
