@@ -9,9 +9,10 @@ def modify(file_path, pass_lines=0, source=None):
             f.readline()
         tokenMod = TokenModifier(f)
         modified = tokenMod.visit()
-        parallel_tokens = tokenMod.parallel_token
+        parallel_tokens = getattr(tokenMod, "parallel_token", None)
     tree = ast.parse(modified)
-    tree = ast.fix_missing_locations(ASTModifier(parallel_tokens).visit(tree))
+    if parallel_tokens:
+        tree = ast.fix_missing_locations(ASTModifier(parallel_tokens).visit(tree))
     if source:
         string = StringIO.StringIO()
         unparse.Unparser(tree, string)
