@@ -6,6 +6,11 @@ from ..config import config
 
 pool = Pool(config.num_greenlet)
 
+
+def import_globals():
+    frame, outerframe = [x[0] for x in inspect.getouterframes(inspect.currentframe())[1:3]]
+    frame.f_globals.update(outerframe.f_globals)
+
 def pmap(f, l):
     return pool.map(f, l)
 
